@@ -16,7 +16,7 @@ from karas.util.Logger import Logging
 from karas.util.network import error_throw, URL_Route, wrap_data_json
 
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 async def _build_content_json(
@@ -105,7 +105,8 @@ class Yurine(object):
             ws: ClientWebSocketResponse = None,
             loggerLevel: str = "INFO",
             logToFile=False,
-            logFileName: str = None
+            logFileName: str = None,
+            logRecordLevel:str = None
     ) -> None:
         self._host = host
         self._port = port
@@ -119,7 +120,7 @@ class Yurine(object):
 
         self.route = URL_Route(self.url)
         self.logging = Logging(
-            loggerLevel, qq, filename=logFileName, logFile=logToFile)
+            loggerLevel, qq, filename=logFileName, logFile=logToFile, recordLevel=logRecordLevel)
         self._loop = loop or self._get_event_loop()
         self.karas = karas or Karas
         self.karas.loop = self.loop
